@@ -2,4 +2,4 @@ from .program import program
 
 
 if __name__ == "__main__":
-    program(prog_name="livermark")
+    program(prog_name="livemark")
