@@ -10,7 +10,9 @@ class BlogPlugin(Plugin):
     validity = {
         "type": "object",
         "properties": {
-            "path": {"type": "string"},
+            "author": {"type": "string"},
+            "image": {"type": "string"},
+            "description": {"type": "string"},
         },
     }
 
@@ -47,6 +49,10 @@ class BlogPlugin(Plugin):
     def image(self):
         return self.config.get("image")
 
+    @property
+    def description(self):
+        return self.config.get("description", self.document.description)
+
     @property
     def date(self):
         if self.path:
